#[non_exhaustive]pub struct DefaultRunSettingBuilder { /* private fields */ }Expand description
A builder for DefaultRunSetting.
Implementations
Sourceimpl DefaultRunSettingBuilder
impl DefaultRunSettingBuilder
Sourcepub fn workflow_id(self, input: impl Into<String>) -> Self
pub fn workflow_id(self, input: impl Into<String>) -> Self
The identifier of the workflow to run.
This field is required.Sourcepub fn set_workflow_id(self, input: Option<String>) -> Self
pub fn set_workflow_id(self, input: Option<String>) -> Self
The identifier of the workflow to run.
Sourcepub fn get_workflow_id(&self) -> &Option<String>
pub fn get_workflow_id(&self) -> &Option<String>
The identifier of the workflow to run.
Sourcepub fn workflow_type(self, input: WorkflowType) -> Self
pub fn workflow_type(self, input: WorkflowType) -> Self
The type of the originating workflow. Batch runs are not supported with READY2RUN workflows.
Sourcepub fn set_workflow_type(self, input: Option<WorkflowType>) -> Self
pub fn set_workflow_type(self, input: Option<WorkflowType>) -> Self
The type of the originating workflow. Batch runs are not supported with READY2RUN workflows.
Sourcepub fn get_workflow_type(&self) -> &Option<WorkflowType>
pub fn get_workflow_type(&self) -> &Option<WorkflowType>
The type of the originating workflow. Batch runs are not supported with READY2RUN workflows.
Sourcepub fn role_arn(self, input: impl Into<String>) -> Self
pub fn role_arn(self, input: impl Into<String>) -> Self
The IAM role ARN that grants HealthOmics permissions to access required AWS resources such as Amazon S3 and CloudWatch. The role must have the same permissions required for individual StartRun calls.
Sourcepub fn set_role_arn(self, input: Option<String>) -> Self
pub fn set_role_arn(self, input: Option<String>) -> Self
The IAM role ARN that grants HealthOmics permissions to access required AWS resources such as Amazon S3 and CloudWatch. The role must have the same permissions required for individual StartRun calls.
Sourcepub fn get_role_arn(&self) -> &Option<String>
pub fn get_role_arn(&self) -> &Option<String>
The IAM role ARN that grants HealthOmics permissions to access required AWS resources such as Amazon S3 and CloudWatch. The role must have the same permissions required for individual StartRun calls.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
An optional user-friendly name applied to each workflow run. Can be overridden per run.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
An optional user-friendly name applied to each workflow run. Can be overridden per run.
Sourcepub fn get_name(&self) -> &Option<String>
pub fn get_name(&self) -> &Option<String>
An optional user-friendly name applied to each workflow run. Can be overridden per run.
Sourcepub fn cache_id(self, input: impl Into<String>) -> Self
pub fn cache_id(self, input: impl Into<String>) -> Self
The identifier of the run cache to associate with the runs.
Sourcepub fn set_cache_id(self, input: Option<String>) -> Self
pub fn set_cache_id(self, input: Option<String>) -> Self
The identifier of the run cache to associate with the runs.
Sourcepub fn get_cache_id(&self) -> &Option<String>
pub fn get_cache_id(&self) -> &Option<String>
The identifier of the run cache to associate with the runs.
Sourcepub fn cache_behavior(self, input: CacheBehavior) -> Self
pub fn cache_behavior(self, input: CacheBehavior) -> Self
The cache behavior for the runs. Requires cacheId to be set.
Sourcepub fn set_cache_behavior(self, input: Option<CacheBehavior>) -> Self
pub fn set_cache_behavior(self, input: Option<CacheBehavior>) -> Self
The cache behavior for the runs. Requires cacheId to be set.
Sourcepub fn get_cache_behavior(&self) -> &Option<CacheBehavior>
pub fn get_cache_behavior(&self) -> &Option<CacheBehavior>
The cache behavior for the runs. Requires cacheId to be set.
Sourcepub fn run_group_id(self, input: impl Into<String>) -> Self
pub fn run_group_id(self, input: impl Into<String>) -> Self
The ID of the run group to contain all workflow runs in the batch.
Sourcepub fn set_run_group_id(self, input: Option<String>) -> Self
pub fn set_run_group_id(self, input: Option<String>) -> Self
The ID of the run group to contain all workflow runs in the batch.
Sourcepub fn get_run_group_id(&self) -> &Option<String>
pub fn get_run_group_id(&self) -> &Option<String>
The ID of the run group to contain all workflow runs in the batch.
Sourcepub fn priority(self, input: i32) -> Self
pub fn priority(self, input: i32) -> Self
An integer priority for the workflow runs. Higher values correspond to higher priority. A value of 0 corresponds to the lowest priority. Can be overridden per run.
Sourcepub fn set_priority(self, input: Option<i32>) -> Self
pub fn set_priority(self, input: Option<i32>) -> Self
An integer priority for the workflow runs. Higher values correspond to higher priority. A value of 0 corresponds to the lowest priority. Can be overridden per run.
Sourcepub fn get_priority(&self) -> &Option<i32>
pub fn get_priority(&self) -> &Option<i32>
An integer priority for the workflow runs. Higher values correspond to higher priority. A value of 0 corresponds to the lowest priority. Can be overridden per run.
Sourcepub fn parameters(self, input: Document) -> Self
pub fn parameters(self, input: Document) -> Self
Workflow parameter names and values shared across all runs. Merged with per-run parameters; run-specific values take precedence when keys overlap. Can be overridden per run.
Sourcepub fn set_parameters(self, input: Option<Document>) -> Self
pub fn set_parameters(self, input: Option<Document>) -> Self
Workflow parameter names and values shared across all runs. Merged with per-run parameters; run-specific values take precedence when keys overlap. Can be overridden per run.
Sourcepub fn get_parameters(&self) -> &Option<Document>
pub fn get_parameters(&self) -> &Option<Document>
Workflow parameter names and values shared across all runs. Merged with per-run parameters; run-specific values take precedence when keys overlap. Can be overridden per run.
Sourcepub fn storage_capacity(self, input: i32) -> Self
pub fn storage_capacity(self, input: i32) -> Self
The filesystem size in gibibytes (GiB) provisioned for each workflow run and shared by all tasks in that run. Defaults to 1200 GiB if not specified.
Sourcepub fn set_storage_capacity(self, input: Option<i32>) -> Self
pub fn set_storage_capacity(self, input: Option<i32>) -> Self
The filesystem size in gibibytes (GiB) provisioned for each workflow run and shared by all tasks in that run. Defaults to 1200 GiB if not specified.
Sourcepub fn get_storage_capacity(&self) -> &Option<i32>
pub fn get_storage_capacity(&self) -> &Option<i32>
The filesystem size in gibibytes (GiB) provisioned for each workflow run and shared by all tasks in that run. Defaults to 1200 GiB if not specified.
Sourcepub fn output_uri(self, input: impl Into<String>) -> Self
pub fn output_uri(self, input: impl Into<String>) -> Self
The destination S3 URI for workflow outputs. Must begin with s3://. The roleArn must grant write permissions to this bucket. Can be overridden per run.
Sourcepub fn set_output_uri(self, input: Option<String>) -> Self
pub fn set_output_uri(self, input: Option<String>) -> Self
The destination S3 URI for workflow outputs. Must begin with s3://. The roleArn must grant write permissions to this bucket. Can be overridden per run.
Sourcepub fn get_output_uri(&self) -> &Option<String>
pub fn get_output_uri(&self) -> &Option<String>
The destination S3 URI for workflow outputs. Must begin with s3://. The roleArn must grant write permissions to this bucket. Can be overridden per run.
Sourcepub fn log_level(self, input: RunLogLevel) -> Self
pub fn log_level(self, input: RunLogLevel) -> Self
The verbosity level for CloudWatch Logs emitted during each run.
Sourcepub fn set_log_level(self, input: Option<RunLogLevel>) -> Self
pub fn set_log_level(self, input: Option<RunLogLevel>) -> Self
The verbosity level for CloudWatch Logs emitted during each run.
Sourcepub fn get_log_level(&self) -> &Option<RunLogLevel>
pub fn get_log_level(&self) -> &Option<RunLogLevel>
The verbosity level for CloudWatch Logs emitted during each run.
Adds a key-value pair to run_tags.
To override the contents of this collection use set_run_tags.
AWS tags to associate with each workflow run. Merged with per-run runTags; run-specific values take precedence when keys overlap.
AWS tags to associate with each workflow run. Merged with per-run runTags; run-specific values take precedence when keys overlap.
AWS tags to associate with each workflow run. Merged with per-run runTags; run-specific values take precedence when keys overlap.
Sourcepub fn retention_mode(self, input: RunRetentionMode) -> Self
pub fn retention_mode(self, input: RunRetentionMode) -> Self
The retention behavior for runs after completion.
Sourcepub fn set_retention_mode(self, input: Option<RunRetentionMode>) -> Self
pub fn set_retention_mode(self, input: Option<RunRetentionMode>) -> Self
The retention behavior for runs after completion.
Sourcepub fn get_retention_mode(&self) -> &Option<RunRetentionMode>
pub fn get_retention_mode(&self) -> &Option<RunRetentionMode>
The retention behavior for runs after completion.
Sourcepub fn storage_type(self, input: StorageType) -> Self
pub fn storage_type(self, input: StorageType) -> Self
The storage type for the workflow runs.
Sourcepub fn set_storage_type(self, input: Option<StorageType>) -> Self
pub fn set_storage_type(self, input: Option<StorageType>) -> Self
The storage type for the workflow runs.
Sourcepub fn get_storage_type(&self) -> &Option<StorageType>
pub fn get_storage_type(&self) -> &Option<StorageType>
The storage type for the workflow runs.
Sourcepub fn workflow_owner_id(self, input: impl Into<String>) -> Self
pub fn workflow_owner_id(self, input: impl Into<String>) -> Self
The AWS account ID of the workflow owner, used for cross-account workflow sharing.
Sourcepub fn set_workflow_owner_id(self, input: Option<String>) -> Self
pub fn set_workflow_owner_id(self, input: Option<String>) -> Self
The AWS account ID of the workflow owner, used for cross-account workflow sharing.
Sourcepub fn get_workflow_owner_id(&self) -> &Option<String>
pub fn get_workflow_owner_id(&self) -> &Option<String>
The AWS account ID of the workflow owner, used for cross-account workflow sharing.
Sourcepub fn output_bucket_owner_id(self, input: impl Into<String>) -> Self
pub fn output_bucket_owner_id(self, input: impl Into<String>) -> Self
The expected AWS account ID of the owner of the output S3 bucket. Can be overridden per run.
Sourcepub fn set_output_bucket_owner_id(self, input: Option<String>) -> Self
pub fn set_output_bucket_owner_id(self, input: Option<String>) -> Self
The expected AWS account ID of the owner of the output S3 bucket. Can be overridden per run.
Sourcepub fn get_output_bucket_owner_id(&self) -> &Option<String>
pub fn get_output_bucket_owner_id(&self) -> &Option<String>
The expected AWS account ID of the owner of the output S3 bucket. Can be overridden per run.
Sourcepub fn workflow_version_name(self, input: impl Into<String>) -> Self
pub fn workflow_version_name(self, input: impl Into<String>) -> Self
The version name of the specified workflow.
Sourcepub fn set_workflow_version_name(self, input: Option<String>) -> Self
pub fn set_workflow_version_name(self, input: Option<String>) -> Self
The version name of the specified workflow.
Sourcepub fn get_workflow_version_name(&self) -> &Option<String>
pub fn get_workflow_version_name(&self) -> &Option<String>
The version name of the specified workflow.
Sourcepub fn networking_mode(self, input: NetworkingMode) -> Self
pub fn networking_mode(self, input: NetworkingMode) -> Self
Optional configuration for run networking behavior. If not specified, this will default to RESTRICTED.
Sourcepub fn set_networking_mode(self, input: Option<NetworkingMode>) -> Self
pub fn set_networking_mode(self, input: Option<NetworkingMode>) -> Self
Optional configuration for run networking behavior. If not specified, this will default to RESTRICTED.
Sourcepub fn get_networking_mode(&self) -> &Option<NetworkingMode>
pub fn get_networking_mode(&self) -> &Option<NetworkingMode>
Optional configuration for run networking behavior. If not specified, this will default to RESTRICTED.
Sourcepub fn configuration_name(self, input: impl Into<String>) -> Self
pub fn configuration_name(self, input: impl Into<String>) -> Self
Optional configuration name to use for the workflow run.
Sourcepub fn set_configuration_name(self, input: Option<String>) -> Self
pub fn set_configuration_name(self, input: Option<String>) -> Self
Optional configuration name to use for the workflow run.
Sourcepub fn get_configuration_name(&self) -> &Option<String>
pub fn get_configuration_name(&self) -> &Option<String>
Optional configuration name to use for the workflow run.
Sourcepub fn engine_settings(self, input: Document) -> Self
pub fn engine_settings(self, input: Document) -> Self
Engine-specific settings for the workflow run. Use this field to specify configuration options that are specific to the workflow engine (for example, Nextflow profiles).
Sourcepub fn set_engine_settings(self, input: Option<Document>) -> Self
pub fn set_engine_settings(self, input: Option<Document>) -> Self
Engine-specific settings for the workflow run. Use this field to specify configuration options that are specific to the workflow engine (for example, Nextflow profiles).
Sourcepub fn get_engine_settings(&self) -> &Option<Document>
pub fn get_engine_settings(&self) -> &Option<Document>
Engine-specific settings for the workflow run. Use this field to specify configuration options that are specific to the workflow engine (for example, Nextflow profiles).
Sourcepub fn scratch_storage_mode(self, input: ScratchStorageMode) -> Self
pub fn scratch_storage_mode(self, input: ScratchStorageMode) -> Self
Optional configuration for enabling scratch ephemeral storage mounted at /tmp. If not specified, this will default to SHARED. This configuration is applicable only for CPU tasks. For tasks using GPUs, scratch storage is always LOCAL.
Sourcepub fn set_scratch_storage_mode(self, input: Option<ScratchStorageMode>) -> Self
pub fn set_scratch_storage_mode(self, input: Option<ScratchStorageMode>) -> Self
Optional configuration for enabling scratch ephemeral storage mounted at /tmp. If not specified, this will default to SHARED. This configuration is applicable only for CPU tasks. For tasks using GPUs, scratch storage is always LOCAL.
Sourcepub fn get_scratch_storage_mode(&self) -> &Option<ScratchStorageMode>
pub fn get_scratch_storage_mode(&self) -> &Option<ScratchStorageMode>
Optional configuration for enabling scratch ephemeral storage mounted at /tmp. If not specified, this will default to SHARED. This configuration is applicable only for CPU tasks. For tasks using GPUs, scratch storage is always LOCAL.
Sourcepub fn build(self) -> Result<DefaultRunSetting, BuildError>
pub fn build(self) -> Result<DefaultRunSetting, BuildError>
Consumes the builder and constructs a DefaultRunSetting.
This method will fail if any of the following fields are not set: