#[non_exhaustive]pub struct InlineSettingBuilder { /* private fields */ }Expand description
A builder for InlineSetting.
Implementations
Sourceimpl InlineSettingBuilder
impl InlineSettingBuilder
Sourcepub fn run_setting_id(self, input: impl Into<String>) -> Self
pub fn run_setting_id(self, input: impl Into<String>) -> Self
A customer-provided unique identifier for this run configuration within the batch. After submission, use ListRunsInBatch to map each runSettingId to the HealthOmics-generated runId.
Sourcepub fn set_run_setting_id(self, input: Option<String>) -> Self
pub fn set_run_setting_id(self, input: Option<String>) -> Self
A customer-provided unique identifier for this run configuration within the batch. After submission, use ListRunsInBatch to map each runSettingId to the HealthOmics-generated runId.
Sourcepub fn get_run_setting_id(&self) -> &Option<String>
pub fn get_run_setting_id(&self) -> &Option<String>
A customer-provided unique identifier for this run configuration within the batch. After submission, use ListRunsInBatch to map each runSettingId to the HealthOmics-generated runId.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
An optional user-friendly name for this run.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
An optional user-friendly name for this run.
Sourcepub fn output_uri(self, input: impl Into<String>) -> Self
pub fn output_uri(self, input: impl Into<String>) -> Self
Override the destination S3 URI for this run's outputs.
Sourcepub fn set_output_uri(self, input: Option<String>) -> Self
pub fn set_output_uri(self, input: Option<String>) -> Self
Override the destination S3 URI for this run's outputs.
Sourcepub fn get_output_uri(&self) -> &Option<String>
pub fn get_output_uri(&self) -> &Option<String>
Override the destination S3 URI for this run's outputs.
Sourcepub fn set_priority(self, input: Option<i32>) -> Self
pub fn set_priority(self, input: Option<i32>) -> Self
Override the priority for this run.
Sourcepub fn get_priority(&self) -> &Option<i32>
pub fn get_priority(&self) -> &Option<i32>
Override the priority for this run.
Sourcepub fn parameters(self, input: Document) -> Self
pub fn parameters(self, input: Document) -> Self
Per-run workflow parameters. Merged with defaultRunSetting.parameters; values in this object take precedence when keys overlap.
Sourcepub fn set_parameters(self, input: Option<Document>) -> Self
pub fn set_parameters(self, input: Option<Document>) -> Self
Per-run workflow parameters. Merged with defaultRunSetting.parameters; values in this object take precedence when keys overlap.
Sourcepub fn get_parameters(&self) -> &Option<Document>
pub fn get_parameters(&self) -> &Option<Document>
Per-run workflow parameters. Merged with defaultRunSetting.parameters; values in this object take precedence when keys overlap.
Sourcepub fn output_bucket_owner_id(self, input: impl Into<String>) -> Self
pub fn output_bucket_owner_id(self, input: impl Into<String>) -> Self
The expected AWS account ID of the owner of the output S3 bucket for this run.
Sourcepub fn set_output_bucket_owner_id(self, input: Option<String>) -> Self
pub fn set_output_bucket_owner_id(self, input: Option<String>) -> Self
The expected AWS account ID of the owner of the output S3 bucket for this run.
Sourcepub fn get_output_bucket_owner_id(&self) -> &Option<String>
pub fn get_output_bucket_owner_id(&self) -> &Option<String>
The expected AWS account ID of the owner of the output S3 bucket for this run.
Adds a key-value pair to run_tags.
To override the contents of this collection use set_run_tags.
Per-run AWS tags. Merged with defaultRunSetting.runTags; values in this object take precedence when keys overlap.
Per-run AWS tags. Merged with defaultRunSetting.runTags; values in this object take precedence when keys overlap.
Per-run AWS tags. Merged with defaultRunSetting.runTags; values in this object take precedence when keys overlap.
Sourcepub fn engine_settings(self, input: Document) -> Self
pub fn engine_settings(self, input: Document) -> Self
Per-run engine-specific settings. Use this field to specify configuration options that are specific to the workflow engine (for example, Nextflow profiles). Overrides defaultRunSetting.engineSettings for this run.
Sourcepub fn set_engine_settings(self, input: Option<Document>) -> Self
pub fn set_engine_settings(self, input: Option<Document>) -> Self
Per-run engine-specific settings. Use this field to specify configuration options that are specific to the workflow engine (for example, Nextflow profiles). Overrides defaultRunSetting.engineSettings for this run.
Sourcepub fn get_engine_settings(&self) -> &Option<Document>
pub fn get_engine_settings(&self) -> &Option<Document>
Per-run engine-specific settings. Use this field to specify configuration options that are specific to the workflow engine (for example, Nextflow profiles). Overrides defaultRunSetting.engineSettings for this run.
Sourcepub fn build(self) -> Result<InlineSetting, BuildError>
pub fn build(self) -> Result<InlineSetting, BuildError>
Consumes the builder and constructs a InlineSetting.
This method will fail if any of the following fields are not set: