#[non_exhaustive]pub enum BatchRunSettings {
InlineSettings(Vec<InlineSetting>),
S3UriSettings(String),
#[non_exhaustive] Unknown,
}Expand description
A union type representing per-run configurations for the batch. Specify exactly one of the following members.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InlineSettings(Vec<InlineSetting>)
A list of per-run configurations provided inline in the request. Each entry must include a unique runSettingId. Supports up to 100 entries. For batches with more than 100 runs, use s3UriSettings.
S3UriSettings(String)
An Amazon S3 URI pointing to a JSON file containing per-run configurations. The file must be a JSON array in the same format as inlineSettings. Supports up to 100,000 run configurations. The maximum file size is 6 GB.
The IAM service role in roleArn must have read access to this S3 object. HealthOmics validates access to the file during the synchronous API call and records the file's ETag. If the file is modified after submission, the batch fails.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl BatchRunSettings
impl BatchRunSettings
Sourcepub fn as_inline_settings(&self) -> Result<&Vec<InlineSetting>, &Self>
pub fn as_inline_settings(&self) -> Result<&Vec<InlineSetting>, &Self>
Tries to convert the enum instance into InlineSettings, extracting the inner Vec.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_inline_settings(&self) -> bool
pub fn is_inline_settings(&self) -> bool
Returns true if this is a InlineSettings.
Sourcepub fn as_s3_uri_settings(&self) -> Result<&String, &Self>
pub fn as_s3_uri_settings(&self) -> Result<&String, &Self>
Tries to convert the enum instance into S3UriSettings, extracting the inner String.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_s3_uri_settings(&self) -> bool
pub fn is_s3_uri_settings(&self) -> bool
Returns true if this is a S3UriSettings.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.