InlineSetting

Struct InlineSetting 

#[non_exhaustive]
pub struct InlineSetting { pub run_setting_id: String, pub name: Option<String>, pub output_uri: Option<String>, pub priority: Option<i32>, pub parameters: Option<Document>, pub output_bucket_owner_id: Option<String>, pub run_tags: Option<HashMap<String, String>>, pub engine_settings: Option<Document>, }
A per-run configuration that overrides or merges with fields from DefaultRunSetting for a specific run.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
run_setting_id: String

A customer-provided unique identifier for this run configuration within the batch. After submission, use ListRunsInBatch to map each runSettingId to the HealthOmics-generated runId.

name: Option<String>

An optional user-friendly name for this run.

output_uri: Option<String>

Override the destination S3 URI for this run's outputs.

priority: Option<i32>

Override the priority for this run.

parameters: Option<Document>

Per-run workflow parameters. Merged with defaultRunSetting.parameters; values in this object take precedence when keys overlap.

output_bucket_owner_id: Option<String>

The expected AWS account ID of the owner of the output S3 bucket for this run.

run_tags: Option<HashMap<String, String>>

Per-run AWS tags. Merged with defaultRunSetting.runTags; values in this object take precedence when keys overlap.

engine_settings: Option<Document>

Per-run engine-specific settings. Use this field to specify configuration options that are specific to the workflow engine (for example, Nextflow profiles). Overrides defaultRunSetting.engineSettings for this run.

Implementations

Source

impl InlineSetting

pub fn run_setting_id(&self) -> &str

A customer-provided unique identifier for this run configuration within the batch. After submission, use ListRunsInBatch to map each runSettingId to the HealthOmics-generated runId.

pub fn name(&self) -> Option<&str>

An optional user-friendly name for this run.

pub fn output_uri(&self) -> Option<&str>

Override the destination S3 URI for this run's outputs.

pub fn priority(&self) -> Option<i32>

Override the priority for this run.

pub fn parameters(&self) -> Option<&Document>

Per-run workflow parameters. Merged with defaultRunSetting.parameters; values in this object take precedence when keys overlap.

pub fn output_bucket_owner_id(&self) -> Option<&str>

The expected AWS account ID of the owner of the output S3 bucket for this run.

pub fn run_tags(&self) -> Option<&HashMap<String, String>>

Per-run AWS tags. Merged with defaultRunSetting.runTags; values in this object take precedence when keys overlap.

pub fn engine_settings(&self) -> Option<&Document>

Per-run engine-specific settings. Use this field to specify configuration options that are specific to the workflow engine (for example, Nextflow profiles). Overrides defaultRunSetting.engineSettings for this run.

Source

impl InlineSetting

pub fn builder() -> InlineSettingBuilder

Creates a new builder-style object to manufacture InlineSetting.