#[non_exhaustive]pub struct DefaultRunSetting {Show 22 fields
pub workflow_id: String,
pub workflow_type: Option<WorkflowType>,
pub role_arn: String,
pub name: Option<String>,
pub cache_id: Option<String>,
pub cache_behavior: Option<CacheBehavior>,
pub run_group_id: Option<String>,
pub priority: Option<i32>,
pub parameters: Option<Document>,
pub storage_capacity: Option<i32>,
pub output_uri: Option<String>,
pub log_level: Option<RunLogLevel>,
pub run_tags: Option<HashMap<String, String>>,
pub retention_mode: Option<RunRetentionMode>,
pub storage_type: Option<StorageType>,
pub workflow_owner_id: Option<String>,
pub output_bucket_owner_id: Option<String>,
pub workflow_version_name: Option<String>,
pub networking_mode: Option<NetworkingMode>,
pub configuration_name: Option<String>,
pub engine_settings: Option<Document>,
pub scratch_storage_mode: Option<ScratchStorageMode>,
}Expand description
Shared configuration applied to all runs in a batch. Fields specified in a per-run InlineSetting entry override the corresponding fields in this object for that run. The parameters and runTags fields are merged rather than replaced — run-specific values take precedence when keys overlap.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workflow_id: StringThe identifier of the workflow to run.
workflow_type: Option<WorkflowType>The type of the originating workflow. Batch runs are not supported with READY2RUN workflows.
role_arn: StringThe IAM role ARN that grants HealthOmics permissions to access required AWS resources such as Amazon S3 and CloudWatch. The role must have the same permissions required for individual StartRun calls.
name: Option<String>An optional user-friendly name applied to each workflow run. Can be overridden per run.
cache_id: Option<String>The identifier of the run cache to associate with the runs.
cache_behavior: Option<CacheBehavior>The cache behavior for the runs. Requires cacheId to be set.
run_group_id: Option<String>The ID of the run group to contain all workflow runs in the batch.
priority: Option<i32>An integer priority for the workflow runs. Higher values correspond to higher priority. A value of 0 corresponds to the lowest priority. Can be overridden per run.
parameters: Option<Document>Workflow parameter names and values shared across all runs. Merged with per-run parameters; run-specific values take precedence when keys overlap. Can be overridden per run.
storage_capacity: Option<i32>The filesystem size in gibibytes (GiB) provisioned for each workflow run and shared by all tasks in that run. Defaults to 1200 GiB if not specified.
output_uri: Option<String>The destination S3 URI for workflow outputs. Must begin with s3://. The roleArn must grant write permissions to this bucket. Can be overridden per run.
log_level: Option<RunLogLevel>The verbosity level for CloudWatch Logs emitted during each run.
AWS tags to associate with each workflow run. Merged with per-run runTags; run-specific values take precedence when keys overlap.
retention_mode: Option<RunRetentionMode>The retention behavior for runs after completion.
storage_type: Option<StorageType>The storage type for the workflow runs.
workflow_owner_id: Option<String>The AWS account ID of the workflow owner, used for cross-account workflow sharing.
output_bucket_owner_id: Option<String>The expected AWS account ID of the owner of the output S3 bucket. Can be overridden per run.
workflow_version_name: Option<String>The version name of the specified workflow.
networking_mode: Option<NetworkingMode>Optional configuration for run networking behavior. If not specified, this will default to RESTRICTED.
configuration_name: Option<String>Optional configuration name to use for the workflow run.
engine_settings: Option<Document>Engine-specific settings for the workflow run. Use this field to specify configuration options that are specific to the workflow engine (for example, Nextflow profiles).
scratch_storage_mode: Option<ScratchStorageMode>Optional configuration for enabling scratch ephemeral storage mounted at /tmp. If not specified, this will default to SHARED. This configuration is applicable only for CPU tasks. For tasks using GPUs, scratch storage is always LOCAL.
Implementations
Sourceimpl DefaultRunSetting
impl DefaultRunSetting
Sourcepub fn workflow_id(&self) -> &str
pub fn workflow_id(&self) -> &str
The identifier of the workflow to run.
Sourcepub fn workflow_type(&self) -> Option<&WorkflowType>
pub fn workflow_type(&self) -> Option<&WorkflowType>
The type of the originating workflow. Batch runs are not supported with READY2RUN workflows.
Sourcepub fn role_arn(&self) -> &str
pub fn role_arn(&self) -> &str
The IAM role ARN that grants HealthOmics permissions to access required AWS resources such as Amazon S3 and CloudWatch. The role must have the same permissions required for individual StartRun calls.
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
An optional user-friendly name applied to each workflow run. Can be overridden per run.
Sourcepub fn cache_id(&self) -> Option<&str>
pub fn cache_id(&self) -> Option<&str>
The identifier of the run cache to associate with the runs.
Sourcepub fn cache_behavior(&self) -> Option<&CacheBehavior>
pub fn cache_behavior(&self) -> Option<&CacheBehavior>
The cache behavior for the runs. Requires cacheId to be set.
Sourcepub fn run_group_id(&self) -> Option<&str>
pub fn run_group_id(&self) -> Option<&str>
The ID of the run group to contain all workflow runs in the batch.
Sourcepub fn priority(&self) -> Option<i32>
pub fn priority(&self) -> Option<i32>
An integer priority for the workflow runs. Higher values correspond to higher priority. A value of 0 corresponds to the lowest priority. Can be overridden per run.
Sourcepub fn parameters(&self) -> Option<&Document>
pub fn parameters(&self) -> Option<&Document>
Workflow parameter names and values shared across all runs. Merged with per-run parameters; run-specific values take precedence when keys overlap. Can be overridden per run.
Sourcepub fn storage_capacity(&self) -> Option<i32>
pub fn storage_capacity(&self) -> Option<i32>
The filesystem size in gibibytes (GiB) provisioned for each workflow run and shared by all tasks in that run. Defaults to 1200 GiB if not specified.
Sourcepub fn output_uri(&self) -> Option<&str>
pub fn output_uri(&self) -> Option<&str>
The destination S3 URI for workflow outputs. Must begin with s3://. The roleArn must grant write permissions to this bucket. Can be overridden per run.
Sourcepub fn log_level(&self) -> Option<&RunLogLevel>
pub fn log_level(&self) -> Option<&RunLogLevel>
The verbosity level for CloudWatch Logs emitted during each run.
AWS tags to associate with each workflow run. Merged with per-run runTags; run-specific values take precedence when keys overlap.
Sourcepub fn retention_mode(&self) -> Option<&RunRetentionMode>
pub fn retention_mode(&self) -> Option<&RunRetentionMode>
The retention behavior for runs after completion.
Sourcepub fn storage_type(&self) -> Option<&StorageType>
pub fn storage_type(&self) -> Option<&StorageType>
The storage type for the workflow runs.
Sourcepub fn workflow_owner_id(&self) -> Option<&str>
pub fn workflow_owner_id(&self) -> Option<&str>
The AWS account ID of the workflow owner, used for cross-account workflow sharing.
Sourcepub fn output_bucket_owner_id(&self) -> Option<&str>
pub fn output_bucket_owner_id(&self) -> Option<&str>
The expected AWS account ID of the owner of the output S3 bucket. Can be overridden per run.
Sourcepub fn workflow_version_name(&self) -> Option<&str>
pub fn workflow_version_name(&self) -> Option<&str>
The version name of the specified workflow.
Sourcepub fn networking_mode(&self) -> Option<&NetworkingMode>
pub fn networking_mode(&self) -> Option<&NetworkingMode>
Optional configuration for run networking behavior. If not specified, this will default to RESTRICTED.
Sourcepub fn configuration_name(&self) -> Option<&str>
pub fn configuration_name(&self) -> Option<&str>
Optional configuration name to use for the workflow run.
Sourcepub fn engine_settings(&self) -> Option<&Document>
pub fn engine_settings(&self) -> Option<&Document>
Engine-specific settings for the workflow run. Use this field to specify configuration options that are specific to the workflow engine (for example, Nextflow profiles).
Sourcepub fn scratch_storage_mode(&self) -> Option<&ScratchStorageMode>
pub fn scratch_storage_mode(&self) -> Option<&ScratchStorageMode>
Optional configuration for enabling scratch ephemeral storage mounted at /tmp. If not specified, this will default to SHARED. This configuration is applicable only for CPU tasks. For tasks using GPUs, scratch storage is always LOCAL.
Sourceimpl DefaultRunSetting
impl DefaultRunSetting
Sourcepub fn builder() -> DefaultRunSettingBuilder
pub fn builder() -> DefaultRunSettingBuilder
Creates a new builder-style object to manufacture DefaultRunSetting.